@@ -56,7 +56,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
         pass
     #result = 'Loaded (%s/%s):%s\n' % (loaded_ifaces, len(ifaces), loaded_list)
     #print result
-    self.show_all()
+    #self.show_all()
 
   def __show_settings_dialog(self, button=None):
     self.__config.load()
@@ -71,7 +71,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
       options = ()
       if config_options:
         options = zip(map(self.__lcl.get, config_options), config_options)
-      config_control = self.__config_ui.create_control(self.__lcl.get_settings(config_key), ck_type, (self.__lcl.get_settings(str(value)), value), options)
+      config_control = self.__config_ui.create_control(self.__lcl.get(config_key), ck_type, (self.__lcl.get(str(value)), value), options)
       if config_control:
         config_controls[config_key] = config_control
         wpa.pack_start(config_control, False)
@@ -91,7 +91,7 @@ class AdvancedInterfaceSwitcherMaemo5(StatusMenuItem):
       controls_keys = config_controls.keys()
       for config_key in config_keys:
         if config_key in controls_keys:
-          name, ck_type, value = config.get_entry(config_key)
+          name, ck_type, value = self.__config.get_entry(config_key)
           value = self.__config_ui.get_value(config_controls[config_key], value, ck_type)
           self.__config.set_value(config_key, value)
       self.__config.save()
